@@ -12,11 +12,12 @@ Copyright (c) 2022 Uber Technologies, Inc.
 */
 
 pub(crate) mod constraint;
+pub(crate) mod default_configs;
 pub(crate) mod edit;
+pub(crate) mod language;
 pub(crate) mod matches;
 pub(crate) mod outgoing_edges;
 pub mod piranha_arguments;
-pub(crate) mod piranha_config;
 pub mod piranha_output;
 pub(crate) mod rule;
 pub(crate) mod rule_graph;
